@@ -25,7 +25,6 @@ import java.util.concurrent.Executor;
 import lombok.Getter;
 import lombok.RequiredArgsConstructor;
 import lombok.extern.slf4j.Slf4j;
-import org.apache.bookkeeper.mledger.impl.PositionImpl;
 import org.jspecify.annotations.Nullable;
 
 /**
@@ -71,7 +70,7 @@ public class ManagedLedgerReplayTask {
 
     private CompletableFuture<Optional<Position>> readAndProcess(
             ManagedCursor cursor, @Nullable Position lastProcessedPosition, EntryProcessor processor) {
-        return readEntries(cursor, maxEntriesPerRead, PositionImpl.LATEST).thenComposeAsync(entries -> {
+        return readEntries(cursor, maxEntriesPerRead, PositionFactory.LATEST).thenComposeAsync(entries -> {
             try {
                 Position processedPosition = lastProcessedPosition;
                 for (final var entry : entries) {
