@@ -20,23 +20,22 @@ package org.apache.pulsar.broker.stats;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
 import org.apache.pulsar.common.stats.Metrics;
-import org.apache.pulsar.common.util.collections.ConcurrentOpenHashMap;
 
 /**
  */
 public class ClusterReplicationMetrics {
     private final List<Metrics> metricsList;
     private final String localCluster;
-    private final ConcurrentOpenHashMap<String, ReplicationMetrics> metricsMap;
+    private final Map<String, ReplicationMetrics> metricsMap = new ConcurrentHashMap<>();
     public static final String SEPARATOR = "_";
     public final boolean metricsEnabled;
 
     public ClusterReplicationMetrics(String localCluster, boolean metricsEnabled) {
         metricsList = new ArrayList<>();
         this.localCluster = localCluster;
-        metricsMap = ConcurrentOpenHashMap.<String, ReplicationMetrics>newBuilder()
-                .build();
         this.metricsEnabled = metricsEnabled;
     }
 
