@@ -634,6 +634,17 @@ public class TopicTransactionBuffer extends TopicTransactionBufferState implemen
         return snapshotAbortedTxnProcessor.clearAbortedTxnSnapshot();
     }
 
+    @Override
+    public CompletableFuture<Void> clearSnapshotAndClose() {
+        if (checkIfClosedAndCleared()) {
+            return CompletableFuture.completedFuture(null);
+        }
+        return snapshotAbortedTxnProcessor.clearAbortedTxnSnapshot().thenCompose(__ -> closeAsync())
+            .thenAccept(__ -> {
+                changeToClosedAndClearedState();
+            });
+    }
+
     @Override
     public CompletableFuture<Void> closeAsync() {
         synchronized (pendingAppendingTxnBufferTasks) {
