@@ -134,6 +134,7 @@ public class WebService implements AutoCloseable {
             httpConfig.addCustomizer(new ForwardedRequestCustomizer());
         }
         httpConfig.setRequestHeaderSize(pulsar.getConfig().getHttpMaxRequestHeaderSize());
+        httpConfig.setIdleTimeout(pulsar.getConfig().getHttpServerIdleTimeout());
         HttpConnectionFactory httpConnectionFactory = new HttpConnectionFactory(httpConfig);
         if (port.isPresent()) {
             List<ConnectionFactory> connectionFactories = new ArrayList<>();
@@ -191,7 +192,10 @@ public class WebService implements AutoCloseable {
         }
 
         // Limit number of concurrent HTTP connections to avoid getting out of file descriptors
-        connectors.forEach(c -> c.setAcceptQueueSize(config.getHttpServerAcceptQueueSize()));
+        connectors.forEach(c -> {
+            c.setAcceptQueueSize(config.getHttpServerAcceptQueueSize());
+            c.setIdleTimeout(pulsar.getConfig().getHttpServerIdleTimeout());
+        });
         server.setConnectors(connectors.toArray(new ServerConnector[connectors.size()]));
 
         filterInitializer = new FilterInitializer(pulsar);
@@ -422,32 +426,52 @@ public class WebService implements AutoCloseable {
 
     @Override
     public void close() throws PulsarServerException {
+        close(true);
+    }
+
+    public void close(boolean waitUtilServerStopped) throws PulsarServerException {
         try {
-            server.stop();
-            // unregister statistics from Prometheus client's default CollectorRegistry singleton
-            // to prevent memory leaks in tests
-            if (jettyStatisticsCollector != null) {
-                try {
-                    CollectorRegistry.defaultRegistry.unregister(jettyStatisticsCollector);
-                } catch (Exception e) {
-                    // ignore any exception happening in unregister
-                    // exception will be thrown for 2. instance of WebService in tests since
-                    // the register supports a single JettyStatisticsCollector
-                }
-                jettyStatisticsCollector = null;
+            if (waitUtilServerStopped) {
+                doClose();
+            } else {
+                Thread webServiceTerminator = new Thread(() -> {
+                    try {
+                        doClose();
+                    } catch (Exception e) {
+                        log.error("Error while closing web service", e);
+                    }
+                });
+                webServiceTerminator.setName("pulsar-web-service-terminator");
+                webServiceTerminator.start();
             }
-            webServiceExecutor.join();
-            if (this.sslContextRefreshTask != null) {
-                this.sslContextRefreshTask.cancel(true);
-            }
-            webExecutorThreadPoolStats.close();
-            this.executorStats.close();
-            log.info("Web service closed");
         } catch (Exception e) {
             throw new PulsarServerException(e);
         }
     }
 
+    private void doClose() throws Exception {
+        server.stop();
+        // unregister statistics from Prometheus client's default CollectorRegistry singleton
+        // to prevent memory leaks in tests
+        if (jettyStatisticsCollector != null) {
+            try {
+                CollectorRegistry.defaultRegistry.unregister(jettyStatisticsCollector);
+            } catch (Exception e) {
+                // ignore any exception happening in unregister
+                // exception will be thrown for 2. instance of WebService in tests since
+                // the register supports a single JettyStatisticsCollector
+            }
+            jettyStatisticsCollector = null;
+        }
+        webServiceExecutor.join();
+        if (this.sslContextRefreshTask != null) {
+            this.sslContextRefreshTask.cancel(true);
+        }
+        webExecutorThreadPoolStats.close();
+        this.executorStats.close();
+        log.info("Web service closed");
+    }
+
     public Optional<Integer> getListenPortHTTP() {
         if (httpConnector != null) {
             return Optional.of(httpConnector.getLocalPort());
