@@ -130,14 +130,16 @@ public class BrokerTestUtil {
 
     /**
      * Logs the topic stats and internal stats for the given topic.
-     * @param logger logger to use
+     *
+     * @param logger      logger to use
      * @param pulsarAdmin PulsarAdmin client to use
-     * @param topic topic name
+     * @param topic       topic name
+     * @param description
      */
-    public static void logTopicStats(Logger logger, PulsarAdmin pulsarAdmin, String topic) {
+    public static void logTopicStats(Logger logger, PulsarAdmin pulsarAdmin, String topic, String description) {
         try {
-            logger.info("[{}] stats: {}", topic, toJson(pulsarAdmin.topics().getStats(topic)));
-            logger.info("[{}] internalStats: {}", topic,
+            logger.info("[{}] {} stats: {}", topic, description, toJson(pulsarAdmin.topics().getStats(topic)));
+            logger.info("[{}] {} internalStats: {}", topic, description,
                     toJson(pulsarAdmin.topics().getInternalStats(topic, true)));
         } catch (PulsarAdminException e) {
             logger.warn("Failed to get stats for topic {}", topic, e);
