@@ -24,6 +24,7 @@ import static org.mockito.Mockito.doThrow;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
 import static org.testng.Assert.assertEquals;
+import static org.testng.Assert.assertNull;
 import static org.testng.Assert.assertTrue;
 import static org.testng.Assert.fail;
 import java.lang.reflect.Field;
@@ -42,6 +43,7 @@ import org.apache.pulsar.common.naming.NamespaceName;
 import org.apache.pulsar.common.policies.data.BookieAffinityGroupData;
 import org.apache.pulsar.common.policies.data.BundlesData;
 import org.apache.pulsar.common.policies.data.ClusterData;
+import org.apache.pulsar.common.policies.data.DelayedDeliveryPolicies;
 import org.apache.pulsar.common.policies.data.DispatchRate;
 import org.apache.pulsar.common.policies.data.Policies;
 import org.apache.pulsar.common.policies.data.PolicyName;
@@ -201,6 +203,45 @@ public class NamespacesV2Test extends MockedPulsarServiceBaseTest {
         assertTrue(Objects.isNull(dispatchRate));
     }
 
+    @Test
+    public void testOperationDelayedDelivery() throws Exception {
+        boolean isActive = true;
+        long tickTime = 1000;
+        long maxDeliveryDelayInMillis = 5000;
+        // 1. set delayed delivery policy
+        namespaces.setDelayedDeliveryPolicies(this.testTenant, this.testNamespace,
+                DelayedDeliveryPolicies.builder()
+                        .active(isActive)
+                        .tickTime(tickTime)
+                        .maxDeliveryDelayInMillis(maxDeliveryDelayInMillis)
+                        .build());
+
+        // 2. query delayed delivery policy & check
+        DelayedDeliveryPolicies policy =
+                (DelayedDeliveryPolicies) asyncRequests(response -> namespaces.getDelayedDeliveryPolicies(response,
+                        this.testTenant, this.testNamespace));
+        assertEquals(policy.isActive(), isActive);
+        assertEquals(policy.getTickTime(), tickTime);
+        assertEquals(policy.getMaxDeliveryDelayInMillis(), maxDeliveryDelayInMillis);
+
+        // 3. remove & check
+        namespaces.removeDelayedDeliveryPolicies(this.testTenant, this.testNamespace);
+        policy =
+                (DelayedDeliveryPolicies) asyncRequests(response -> namespaces.getDelayedDeliveryPolicies(response,
+                        this.testTenant, this.testNamespace));
+        assertTrue(Objects.isNull(policy));
+
+        // 4. invalid namespace check
+        String invalidNamespace = this.testNamespace + "/";
+        try {
+            namespaces.setDelayedDeliveryPolicies(this.testTenant, invalidNamespace,
+                    DelayedDeliveryPolicies.builder().build());
+            fail("should have failed");
+        } catch (RestException e) {
+            assertEquals(e.getResponse().getStatus(), Response.Status.PRECONDITION_FAILED.getStatusCode());
+        }
+    }
+
     @Test
     public void testSetBookieAffinityGroupWithEmptyPolicies() throws Exception {
         // 1. create namespace with empty policies
@@ -213,7 +254,8 @@ public class NamespacesV2Test extends MockedPulsarServiceBaseTest {
         BookieAffinityGroupData bookieAffinityGroupDataReq =
                 BookieAffinityGroupData.builder().bookkeeperAffinityGroupPrimary(primaryAffinityGroup)
                         .bookkeeperAffinityGroupSecondary(secondaryAffinityGroup).build();
-        namespaces.setBookieAffinityGroup(testTenant, setBookieAffinityGroupNs, bookieAffinityGroupDataReq);
+        asyncRequests(response -> namespaces.setBookieAffinityGroup(response, testTenant, setBookieAffinityGroupNs,
+                bookieAffinityGroupDataReq));
 
         // 3.query namespace num bundles, should be conf.getDefaultNumberOfNamespaceBundles()
         BundlesData bundlesData = (BundlesData) asyncRequests(
@@ -221,8 +263,8 @@ public class NamespacesV2Test extends MockedPulsarServiceBaseTest {
         assertEquals(bundlesData.getNumBundles(), conf.getDefaultNumberOfNamespaceBundles());
 
         // 4.assert namespace bookie affinity group
-        BookieAffinityGroupData bookieAffinityGroupDataResp =
-                namespaces.getBookieAffinityGroup(testTenant, setBookieAffinityGroupNs);
+        BookieAffinityGroupData bookieAffinityGroupDataResp = (BookieAffinityGroupData) asyncRequests(
+                response -> namespaces.getBookieAffinityGroup(response, testTenant, setBookieAffinityGroupNs));
         assertEquals(bookieAffinityGroupDataResp, bookieAffinityGroupDataReq);
     }
 
@@ -240,7 +282,8 @@ public class NamespacesV2Test extends MockedPulsarServiceBaseTest {
         BookieAffinityGroupData bookieAffinityGroupDataReq =
                 BookieAffinityGroupData.builder().bookkeeperAffinityGroupPrimary(primaryAffinityGroup)
                         .bookkeeperAffinityGroupSecondary(secondaryAffinityGroup).build();
-        namespaces.setBookieAffinityGroup(testTenant, setBookieAffinityGroupNs, bookieAffinityGroupDataReq);
+        asyncRequests(response -> namespaces.setBookieAffinityGroup(response, testTenant, setBookieAffinityGroupNs,
+                bookieAffinityGroupDataReq));
 
         // 3.query namespace num bundles, should be policies.bundles, which we set before
         BundlesData bundlesData = (BundlesData) asyncRequests(
@@ -248,8 +291,8 @@ public class NamespacesV2Test extends MockedPulsarServiceBaseTest {
         assertEquals(bundlesData, policies.bundles);
 
         // 4.assert namespace bookie affinity group
-        BookieAffinityGroupData bookieAffinityGroupDataResp =
-                namespaces.getBookieAffinityGroup(testTenant, setBookieAffinityGroupNs);
+        BookieAffinityGroupData bookieAffinityGroupDataResp = (BookieAffinityGroupData) asyncRequests(
+                response -> namespaces.getBookieAffinityGroup(response, testTenant, setBookieAffinityGroupNs));
         assertEquals(bookieAffinityGroupDataResp, bookieAffinityGroupDataReq);
     }
 
@@ -300,4 +343,79 @@ public class NamespacesV2Test extends MockedPulsarServiceBaseTest {
                 namespaces.getNamespaceAntiAffinityGroup(testTenant, setNamespaceAntiAffinityGroupNs);
         assertEquals(namespaceAntiAffinityGroupResp, namespaceAntiAffinityGroupReq);
     }
+
+    @Test
+    public void testEnableMigrationWithEmptyPolicies() throws Exception {
+        // 1. create namespace with empty policies
+        String enableMigrationGroupNs = "test-set-namespace-enable-migration-ns";
+        asyncRequests(response -> namespaces.createNamespace(response, testTenant, enableMigrationGroupNs, null));
+
+        // 2.set enable migration
+        boolean enableMigrationReq = true;
+        namespaces.enableMigration(testTenant, enableMigrationGroupNs, enableMigrationReq);
+
+        // 3.query namespace num bundles, should be conf.getDefaultNumberOfNamespaceBundles()
+        BundlesData bundlesData = (BundlesData) asyncRequests(
+                response -> namespaces.getBundlesData(response, testTenant, enableMigrationGroupNs));
+        assertEquals(bundlesData.getNumBundles(), conf.getDefaultNumberOfNamespaceBundles());
+
+        // 4.assert namespace enable migration
+        Policies policiesResp = (Policies) asyncRequests(
+                response -> namespaces.getPolicies(response, testTenant, enableMigrationGroupNs));
+        assertEquals(policiesResp.migrated, enableMigrationReq);
+    }
+
+    @Test
+    public void testEnableMigrationWithExistBundlePolicies() throws Exception {
+        // 1. create namespace with specified num bundles
+        String enableMigrationGroupNs = "test-set-namespace-enable-migration-ns";
+        Policies policiesReq = new Policies();
+        policiesReq.bundles = getBundles(10);
+        asyncRequests(
+                response -> namespaces.createNamespace(response, testTenant, enableMigrationGroupNs, policiesReq));
+
+        // 2.set enable migration
+        boolean enableMigrationReq = true;
+        namespaces.enableMigration(testTenant, enableMigrationGroupNs, enableMigrationReq);
+
+        // 3.query namespace num bundles, should be policies.bundles, which we set before
+        BundlesData bundlesData = (BundlesData) asyncRequests(
+                response -> namespaces.getBundlesData(response, testTenant, enableMigrationGroupNs));
+        assertEquals(bundlesData, policiesReq.bundles);
+
+        // 4.assert namespace enable migration
+        Policies policiesResp = (Policies) asyncRequests(
+                response -> namespaces.getPolicies(response, testTenant, enableMigrationGroupNs));
+        assertEquals(policiesResp.migrated, enableMigrationReq);
+    }
+
+    @Test
+    public void testSetAndDeleteBookieAffinityGroup() throws Exception {
+        // 1. create namespace with empty policies
+        String setBookieAffinityGroupNs = "test-set-bookie-affinity-group-ns";
+        asyncRequests(response -> namespaces.createNamespace(response, testTenant, setBookieAffinityGroupNs, null));
+
+        // 2.set bookie affinity group
+        String primaryAffinityGroup = "primary-affinity-group";
+        String secondaryAffinityGroup = "secondary-affinity-group";
+        BookieAffinityGroupData bookieAffinityGroupDataReq =
+                BookieAffinityGroupData.builder().bookkeeperAffinityGroupPrimary(primaryAffinityGroup)
+                        .bookkeeperAffinityGroupSecondary(secondaryAffinityGroup).build();
+        asyncRequests(response -> namespaces.setBookieAffinityGroup(response, testTenant, setBookieAffinityGroupNs,
+                bookieAffinityGroupDataReq));
+
+        // 3.assert namespace bookie affinity group
+        BookieAffinityGroupData bookieAffinityGroupDataResp = (BookieAffinityGroupData) asyncRequests(
+                response -> namespaces.getBookieAffinityGroup(response, testTenant, setBookieAffinityGroupNs));
+        assertEquals(bookieAffinityGroupDataResp, bookieAffinityGroupDataReq);
+
+        // 4.delete bookie affinity group
+        asyncRequests(response -> namespaces.deleteBookieAffinityGroup(response, testTenant, setBookieAffinityGroupNs));
+
+        // 5.assert namespace bookie affinity group
+        bookieAffinityGroupDataResp = (BookieAffinityGroupData) asyncRequests(
+                response -> namespaces.getBookieAffinityGroup(response, testTenant, setBookieAffinityGroupNs));
+        assertNull(bookieAffinityGroupDataResp);
+    }
+
 }
