@@ -31,6 +31,7 @@ import java.util.concurrent.ConcurrentSkipListMap;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
+import java.util.concurrent.atomic.LongAdder;
 import org.apache.bookkeeper.mledger.Position;
 import org.apache.commons.lang3.tuple.Pair;
 import org.apache.pulsar.broker.ServiceConfiguration;
@@ -173,10 +174,7 @@ public class TransactionMetadataStoreServiceTest extends BrokerTestBase {
                 (MLTransactionMetadataStore) pulsar.getTransactionMetadataStoreService()
                         .getStores().get(TransactionCoordinatorID.get(0));
         checkTransactionMetadataStoreReady(transactionMetadataStore);
-        Field field = MLTransactionMetadataStore.class.getDeclaredField("txnMetaMap");
-        field.setAccessible(true);
-        ConcurrentSkipListMap<Long, Pair<TxnMeta, List<Position>>> txnMap =
-                (ConcurrentSkipListMap<Long, Pair<TxnMeta, List<Position>>>) field.get(transactionMetadataStore);
+        ConcurrentSkipListMap<Long, Pair<TxnMeta, List<Position>>> txnMap = transactionMetadataStore.getTxnMetaMap();
         int i = -1;
         while (++i < 1000) {
             try {
@@ -189,7 +187,7 @@ public class TransactionMetadataStoreServiceTest extends BrokerTestBase {
         txnMap.forEach((txnID, txnMetaListPair) ->
                 Assert.assertEquals(txnMetaListPair.getLeft().status(), TxnStatus.OPEN));
         Awaitility.await().atLeast(1000, TimeUnit.MICROSECONDS)
-                .until(() -> txnMap.size() == 0);
+                .until(() -> transactionMetadataStore.getOnGoingTxnCount().intValue() == 0);
     }
 
     private TxnID newTransactionWithTimeoutOf(long timeout)
@@ -209,25 +207,23 @@ public class TransactionMetadataStoreServiceTest extends BrokerTestBase {
                 (MLTransactionMetadataStore) pulsar.getTransactionMetadataStoreService()
                         .getStores().get(TransactionCoordinatorID.get(0));
         checkTransactionMetadataStoreReady(transactionMetadataStore);
-        Field field = MLTransactionMetadataStore.class.getDeclaredField("txnMetaMap");
-        field.setAccessible(true);
-        ConcurrentSkipListMap<Long, Pair<TxnMeta, List<Position>>> txnMap =
-                (ConcurrentSkipListMap<Long, Pair<TxnMeta, List<Position>>>) field.get(transactionMetadataStore);
+        ConcurrentSkipListMap<Long, Pair<TxnMeta, List<Position>>> txnMap = transactionMetadataStore.getTxnMetaMap();
+        LongAdder onGoingTxtCount = transactionMetadataStore.getOnGoingTxnCount();
 
         newTransactionWithTimeoutOf(2000);
 
-        assertEquals(txnMap.size(), 1);
+        assertEquals(onGoingTxtCount.intValue(), 1);
 
         txnMap.forEach((txnID, txnMetaListPair) ->
                 Assert.assertEquals(txnMetaListPair.getLeft().status(), TxnStatus.OPEN));
-        Awaitility.await().atLeast(1000, TimeUnit.MICROSECONDS).until(() -> txnMap.size() == 0);
+        Awaitility.await().atLeast(1000, TimeUnit.MICROSECONDS).until(() -> onGoingTxtCount.intValue() == 0);
 
         newTransactionWithTimeoutOf(2000);
-        assertEquals(txnMap.size(), 1);
+        assertEquals(onGoingTxtCount.intValue(), 1);
 
         txnMap.forEach((txnID, txnMetaListPair) ->
                 Assert.assertEquals(txnMetaListPair.getLeft().status(), TxnStatus.OPEN));
-        Awaitility.await().atLeast(1000, TimeUnit.MICROSECONDS).until(() -> txnMap.size() == 0);
+        Awaitility.await().atLeast(1000, TimeUnit.MICROSECONDS).until(() -> onGoingTxtCount.intValue() == 0);
     }
 
     @Test
@@ -241,10 +237,7 @@ public class TransactionMetadataStoreServiceTest extends BrokerTestBase {
                         .getStores().get(TransactionCoordinatorID.get(0));
 
         checkTransactionMetadataStoreReady(transactionMetadataStore);
-        Field field = MLTransactionMetadataStore.class.getDeclaredField("txnMetaMap");
-        field.setAccessible(true);
-        ConcurrentSkipListMap<Long, Pair<TxnMeta, List<Position>>> txnMap =
-                (ConcurrentSkipListMap<Long, Pair<TxnMeta, List<Position>>>) field.get(transactionMetadataStore);
+        LongAdder onGoingTxtCount = transactionMetadataStore.getOnGoingTxnCount();
         new Thread(() -> {
             int i = -1;
             while (++i < 100) {
@@ -289,15 +282,15 @@ public class TransactionMetadataStoreServiceTest extends BrokerTestBase {
             }
         }).start();
 
-        checkoutTimeout(txnMap, 300);
-        checkoutTimeout(txnMap, 200);
-        checkoutTimeout(txnMap, 100);
-        checkoutTimeout(txnMap, 0);
+        checkoutTimeout(onGoingTxtCount, 300);
+        checkoutTimeout(onGoingTxtCount, 200);
+        checkoutTimeout(onGoingTxtCount, 100);
+        checkoutTimeout(onGoingTxtCount, 0);
     }
 
-    private void checkoutTimeout(ConcurrentSkipListMap<Long, Pair<TxnMeta, List<Position>>> txnMap, int time) {
+    private void checkoutTimeout(LongAdder onGoingTxtCount, int time) {
         Awaitility.await().atLeast(1000, TimeUnit.MICROSECONDS)
-                .until(() -> txnMap.size() == time);
+                .until(() -> onGoingTxtCount.intValue() == time);
     }
 
     @Test
@@ -326,12 +319,8 @@ public class TransactionMetadataStoreServiceTest extends BrokerTestBase {
                         .getStores().get(TransactionCoordinatorID.get(0));
 
         checkTransactionMetadataStoreReady(transactionMetadataStore);
-
-        Field field = MLTransactionMetadataStore.class.getDeclaredField("txnMetaMap");
-        field.setAccessible(true);
-        ConcurrentSkipListMap<Long, Pair<TxnMeta, List<Position>>> txnMap =
-                (ConcurrentSkipListMap<Long, Pair<TxnMeta, List<Position>>>) field.get(transactionMetadataStore);
-        Awaitility.await().until(() -> txnMap.size() == 0);
+        LongAdder onGoingTxtCount = transactionMetadataStore.getOnGoingTxnCount();
+        Awaitility.await().until(() -> onGoingTxtCount.intValue() == 0);
 
     }
 
