@@ -46,6 +46,7 @@ import lombok.Cleanup;
 import lombok.extern.slf4j.Slf4j;
 import org.apache.bookkeeper.mledger.Position;
 import org.apache.bookkeeper.mledger.impl.ManagedLedgerImpl;
+import org.apache.pulsar.broker.BrokerTestUtil;
 import org.apache.pulsar.broker.TransactionMetadataStoreService;
 import org.apache.pulsar.broker.service.BrokerService;
 import org.apache.pulsar.broker.service.Topic;
@@ -177,7 +178,7 @@ public class TransactionEndToEndTest extends TransactionTestBase {
     }
 
 
-    @Test(dataProvider="enableBatch")
+    @Test(dataProvider = "enableBatch")
     private void testFilterMsgsInPendingAckStateWhenConsumerDisconnect(boolean enableBatch) throws Exception {
         final String topicName = NAMESPACE1 + "/testFilterMsgsInPendingAckStateWhenConsumerDisconnect-" + enableBatch;
         final int count = 10;
@@ -247,9 +248,9 @@ public class TransactionEndToEndTest extends TransactionTestBase {
         txn1.abort().get();
         // after txn1 aborted, consumer will receive messages txn1 contains
         int receiveCounter = 0;
-        while((message = consumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS)) != null) {
+        while ((message = consumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS)) != null) {
             Assert.assertEquals(message.getValue().intValue(), receiveCounter);
-            receiveCounter ++;
+            receiveCounter++;
         }
         Assert.assertEquals(receiveCounter, count / 2);
     }
@@ -313,7 +314,7 @@ public class TransactionEndToEndTest extends TransactionTestBase {
         }
     }
 
-    @Test(dataProvider="enableBatch")
+    @Test(dataProvider = "enableBatch")
     private void produceCommitTest(boolean enableBatch) throws Exception {
         @Cleanup
         Consumer<byte[]> consumer = pulsarClient
@@ -357,7 +358,7 @@ public class TransactionEndToEndTest extends TransactionTestBase {
         for (int i = 0; i < txnMessageCnt; i++) {
             message = consumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS);
             Assert.assertNotNull(message);
-            receiveCnt ++;
+            receiveCnt++;
         }
         Assert.assertEquals(txnMessageCnt, receiveCnt);
 
@@ -408,7 +409,7 @@ public class TransactionEndToEndTest extends TransactionTestBase {
         Assert.assertNull(message);
         Awaitility.await().until(() -> {
             boolean flag = true;
-            for (int partition = 0; partition < TOPIC_PARTITION; partition ++) {
+            for (int partition = 0; partition < TOPIC_PARTITION; partition++) {
                 String topic;
                 topic = TopicName.get(TOPIC_OUTPUT).getPartition(partition).toString();
                 boolean exist = false;
@@ -429,8 +430,10 @@ public class TransactionEndToEndTest extends TransactionTestBase {
                             if (!markDeletePosition.equals(lastConfirmedEntry)) {
                                 //this because of the transaction commit marker have't delete
                                 //delete commit marker after ack position
-                                //when delete commit marker operation is processing, next delete operation will not do again
-                                //when delete commit marker operation finish, it can run next delete commit marker operation
+                                //when delete commit marker operation is processing,
+                                // next delete operation will not do again
+                                //when delete commit marker operation finish,
+                                // it can run next delete commit marker operation
                                 //so this test may not delete all the position in this manageLedger.
                                 Position markerPosition = ((ManagedLedgerImpl) persistentSubscription.getCursor()
                                         .getManagedLedger()).getNextValidPosition(markDeletePosition);
@@ -455,8 +458,76 @@ public class TransactionEndToEndTest extends TransactionTestBase {
         log.info("finished test partitionAbortTest");
     }
 
-    @Test(dataProvider="enableBatch")
-    private void testAckWithTransactionReduceUnAckMessageCount(boolean enableBatch) throws Exception {
+    @DataProvider
+    public Object[][] unackMessagesCountParams() {
+        return new Object[][] {
+                // batchSend, batchAck, asyncAck
+                {Boolean.TRUE, Boolean.TRUE, Boolean.TRUE},
+                {Boolean.TRUE, Boolean.TRUE, Boolean.FALSE},
+                {Boolean.TRUE, Boolean.FALSE, Boolean.TRUE},
+                {Boolean.TRUE, Boolean.FALSE, Boolean.FALSE},
+                {Boolean.FALSE, Boolean.TRUE, Boolean.TRUE},
+                {Boolean.FALSE, Boolean.TRUE, Boolean.FALSE},
+                {Boolean.FALSE, Boolean.FALSE, Boolean.TRUE},
+                {Boolean.FALSE, Boolean.FALSE, Boolean.FALSE}
+        };
+    }
+
+    @Test(dataProvider = "unackMessagesCountParams")
+    public void testUnackMessageAfterAckAllMessages(boolean batchSend, boolean batchAck, boolean asyncAck)
+            throws Exception {
+        final int messageCount = 50;
+        final String subName = "s1";
+        final String topicName = BrokerTestUtil.newUniqueName(NAMESPACE1 + "/tp");
+        // Create producer and consumer.
+        Consumer<byte[]> consumer = pulsarClient.newConsumer().topic(topicName).subscriptionName(subName)
+                .subscriptionType(SubscriptionType.Shared).isAckReceiptEnabled(true).subscribe();
+        Awaitility.await().until(consumer::isConnected);
+        Producer<byte[]> producer = pulsarClient.newProducer().topic(topicName).enableBatching(batchSend)
+                .batchingMaxMessages(10).create();
+        Awaitility.await().until(producer::isConnected);
+        // Publish messages.
+        CompletableFuture<MessageId> latestSendFuture = null;
+        for (int i = 0; i < messageCount; i++) {
+            latestSendFuture = producer.sendAsync((i + "").getBytes());
+        }
+        latestSendFuture.join();
+
+        // Ack messages with TXN.
+        Transaction txn = getTxn();
+        List<MessageId> msgIds = new ArrayList<>();
+        for (int i = 0; i < messageCount; i++) {
+            Message<byte[]> message = consumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS);
+            msgIds.add(message.getMessageId());
+        }
+        if (batchAck) {
+            consumer.acknowledgeAsync(msgIds, txn).get();
+        } else if (asyncAck) {
+            CompletableFuture<Void> latestAckFuture = null;
+            for (MessageId msgId : msgIds) {
+                latestAckFuture = consumer.acknowledgeAsync(msgId, txn);
+            }
+            latestAckFuture.join();
+        } else {
+            for (MessageId msgId : msgIds) {
+                consumer.acknowledgeAsync(msgId, txn).get();
+            }
+        }
+        txn.commit().get();
+
+        // Verify: the quantity of un-ack messages is 0.
+        int unAckMsgs = admin.topics().getStats(topicName).getSubscriptions().get(subName).getConsumers().get(0)
+                .getUnackedMessages();
+        assertEquals(unAckMsgs, 0);
+
+        // cleanup.
+        producer.close();
+        consumer.close();
+        admin.topics().delete(topicName, true);
+    }
+
+    @Test(dataProvider = "enableBatch")
+    public void testAckWithTransactionReduceUnAckMessageCount(boolean enableBatch) throws Exception {
 
         final int messageCount = 50;
         final String subName = "testAckWithTransactionReduceUnAckMessageCount";
@@ -681,10 +752,10 @@ public class TransactionEndToEndTest extends TransactionTestBase {
         for (int i = 0; i < messageCnt; i++) {
             message = consumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS);
             Assert.assertNotNull(message);
-            receiveCnt ++;
+            receiveCnt++;
             if (i % 2 == 0) {
                 consumer.acknowledge(message);
-                ackedMessageCount ++;
+                ackedMessageCount++;
             }
         }
         Assert.assertEquals(messageCnt, receiveCnt);
@@ -704,7 +775,7 @@ public class TransactionEndToEndTest extends TransactionTestBase {
             message = consumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS);
             Assert.assertNotNull(message);
             consumer.acknowledge(message);
-            receiveCnt ++;
+            receiveCnt++;
         }
         Assert.assertEquals(messageCnt - ackedMessageCount, receiveCnt);
 
@@ -1176,9 +1247,11 @@ public class TransactionEndToEndTest extends TransactionTestBase {
         }
         Transaction txn = getTxn();
         if (ackType == CommandAck.AckType.Individual) {
-            consumer.acknowledgeAsync(consumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS).getMessageId(), txn);
+            consumer.acknowledgeAsync(consumer.receive(waitTimeForCanReceiveMsgInSec,
+                    TimeUnit.SECONDS).getMessageId(), txn);
         } else {
-            consumer.acknowledgeCumulativeAsync(consumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS).getMessageId(), txn);
+            consumer.acknowledgeCumulativeAsync(consumer.receive(waitTimeForCanReceiveMsgInSec,
+                    TimeUnit.SECONDS).getMessageId(), txn);
         }
         topic = TopicName.get(topic).toString();
         boolean exist = false;
@@ -1288,7 +1361,7 @@ public class TransactionEndToEndTest extends TransactionTestBase {
                 .build().get();
         producer.newMessage().send();
         Awaitility.await().untilAsserted(() -> {
-            Assert.assertEquals(((TransactionImpl)transaction).getState(), TransactionImpl.State.TIME_OUT);
+            Assert.assertEquals(((TransactionImpl) transaction).getState(), TransactionImpl.State.TIME_OUT);
         });
 
         try {
@@ -1511,7 +1584,8 @@ public class TransactionEndToEndTest extends TransactionTestBase {
                 .build().get();
 
         // consumer receive the message the first time, redeliverCount = 0
-        consumer.acknowledgeAsync(consumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS).getMessageId(), transaction).get();
+        consumer.acknowledgeAsync(consumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS)
+                .getMessageId(), transaction).get();
 
         transaction.abort().get();
 
@@ -1519,7 +1593,8 @@ public class TransactionEndToEndTest extends TransactionTestBase {
                 .build().get();
 
         // consumer receive the message the second time, redeliverCount = 1, also can be received
-        consumer.acknowledgeAsync(consumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS).getMessageId(), transaction).get();
+        consumer.acknowledgeAsync(consumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS)
+                .getMessageId(), transaction).get();
 
         transaction.abort().get();
 
@@ -1529,7 +1604,8 @@ public class TransactionEndToEndTest extends TransactionTestBase {
 
         assertEquals(((ConsumerImpl<?>) consumer).getAvailablePermits(), 3);
 
-        assertEquals(value, new String(deadLetterConsumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS).getValue()));
+        assertEquals(value, new String(deadLetterConsumer
+                .receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS).getValue()));
 
         // cleanup.
         consumer.close();
@@ -1582,7 +1658,7 @@ public class TransactionEndToEndTest extends TransactionTestBase {
 
         // consumer will receive the batch message two and then receive
         // the message one and message two again, redeliverCount = 1
-        for (int i = 0; i < 3; i ++) {
+        for (int i = 0; i < 3; i++) {
             message = consumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS);
         }
 
@@ -1601,8 +1677,10 @@ public class TransactionEndToEndTest extends TransactionTestBase {
 
         assertEquals(((ConsumerImpl<?>) consumer).getAvailablePermits(), 6);
 
-        assertEquals(value1, new String(deadLetterConsumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS).getValue()));
-        assertEquals(value2, new String(deadLetterConsumer.receive(waitTimeForCanReceiveMsgInSec, TimeUnit.SECONDS).getValue()));
+        assertEquals(value1, new String(deadLetterConsumer.receive(waitTimeForCanReceiveMsgInSec,
+                TimeUnit.SECONDS).getValue()));
+        assertEquals(value2, new String(deadLetterConsumer.receive(waitTimeForCanReceiveMsgInSec,
+                TimeUnit.SECONDS).getValue()));
 
         // cleanup.
         consumer.close();
