@@ -138,7 +138,8 @@ public class TopicCompactionServiceTest extends MockedPulsarServiceBaseTest {
 
         CompactedTopicImpl compactedTopic = service.getCompactedTopic();
 
-        Long compactedLedger = admin.topics().getInternalStats(topic).cursors.get(COMPACTION_SUBSCRIPTION).properties.get(
+        Long compactedLedger =
+                admin.topics().getInternalStats(topic).cursors.get(COMPACTION_SUBSCRIPTION).properties.get(
                 COMPACTED_TOPIC_LEDGER_PROPERTY);
         String markDeletePosition =
                 admin.topics().getInternalStats(topic).cursors.get(COMPACTION_SUBSCRIPTION).markDeletePosition;
