@@ -19,6 +19,7 @@
 package org.apache.pulsar.client.admin.internal;
 
 import static com.google.common.base.Preconditions.checkArgument;
+import com.google.common.annotations.VisibleForTesting;
 import java.io.IOException;
 import java.net.URL;
 import java.util.Map;
@@ -159,29 +160,29 @@ public class PulsarAdminImpl implements PulsarAdmin {
                 Math.toIntExact(clientConfigData.getRequestTimeoutMs()),
                 clientConfigData.getAutoCertRefreshSeconds());
 
-        long readTimeoutMs = clientConfigData.getReadTimeoutMs();
-        this.clusters = new ClustersImpl(root, auth, readTimeoutMs);
-        this.brokers = new BrokersImpl(root, auth, readTimeoutMs);
-        this.brokerStats = new BrokerStatsImpl(root, auth, readTimeoutMs);
-        this.proxyStats = new ProxyStatsImpl(root, auth, readTimeoutMs);
-        this.tenants = new TenantsImpl(root, auth, readTimeoutMs);
-        this.resourcegroups = new ResourceGroupsImpl(root, auth, readTimeoutMs);
-        this.properties = new TenantsImpl(root, auth, readTimeoutMs);
-        this.namespaces = new NamespacesImpl(root, auth, readTimeoutMs);
-        this.topics = new TopicsImpl(root, auth, readTimeoutMs);
-        this.localTopicPolicies = new TopicPoliciesImpl(root, auth, readTimeoutMs, false);
-        this.globalTopicPolicies = new TopicPoliciesImpl(root, auth, readTimeoutMs, true);
-        this.nonPersistentTopics = new NonPersistentTopicsImpl(root, auth, readTimeoutMs);
-        this.resourceQuotas = new ResourceQuotasImpl(root, auth, readTimeoutMs);
-        this.lookups = new LookupImpl(root, auth, useTls, readTimeoutMs, topics);
-        this.functions = new FunctionsImpl(root, auth, asyncHttpConnector.getHttpClient(), readTimeoutMs);
-        this.sources = new SourcesImpl(root, auth, asyncHttpConnector.getHttpClient(), readTimeoutMs);
-        this.sinks = new SinksImpl(root, auth, asyncHttpConnector.getHttpClient(), readTimeoutMs);
-        this.worker = new WorkerImpl(root, auth, readTimeoutMs);
-        this.schemas = new SchemasImpl(root, auth, readTimeoutMs);
-        this.bookies = new BookiesImpl(root, auth, readTimeoutMs);
-        this.packages = new PackagesImpl(root, auth, asyncHttpConnector.getHttpClient(), readTimeoutMs);
-        this.transactions = new TransactionsImpl(root, auth, readTimeoutMs);
+        long requestTimeoutMs = clientConfigData.getRequestTimeoutMs();
+        this.clusters = new ClustersImpl(root, auth, requestTimeoutMs);
+        this.brokers = new BrokersImpl(root, auth, requestTimeoutMs);
+        this.brokerStats = new BrokerStatsImpl(root, auth, requestTimeoutMs);
+        this.proxyStats = new ProxyStatsImpl(root, auth, requestTimeoutMs);
+        this.tenants = new TenantsImpl(root, auth, requestTimeoutMs);
+        this.resourcegroups = new ResourceGroupsImpl(root, auth, requestTimeoutMs);
+        this.properties = new TenantsImpl(root, auth, requestTimeoutMs);
+        this.namespaces = new NamespacesImpl(root, auth, requestTimeoutMs);
+        this.topics = new TopicsImpl(root, auth, requestTimeoutMs);
+        this.localTopicPolicies = new TopicPoliciesImpl(root, auth, requestTimeoutMs, false);
+        this.globalTopicPolicies = new TopicPoliciesImpl(root, auth, requestTimeoutMs, true);
+        this.nonPersistentTopics = new NonPersistentTopicsImpl(root, auth, requestTimeoutMs);
+        this.resourceQuotas = new ResourceQuotasImpl(root, auth, requestTimeoutMs);
+        this.lookups = new LookupImpl(root, auth, useTls, requestTimeoutMs, topics);
+        this.functions = new FunctionsImpl(root, auth, asyncHttpConnector, requestTimeoutMs);
+        this.sources = new SourcesImpl(root, auth, asyncHttpConnector, requestTimeoutMs);
+        this.sinks = new SinksImpl(root, auth, asyncHttpConnector, requestTimeoutMs);
+        this.worker = new WorkerImpl(root, auth, requestTimeoutMs);
+        this.schemas = new SchemasImpl(root, auth, requestTimeoutMs);
+        this.bookies = new BookiesImpl(root, auth, requestTimeoutMs);
+        this.packages = new PackagesImpl(root, auth, asyncHttpConnector, requestTimeoutMs);
+        this.transactions = new TransactionsImpl(root, auth, requestTimeoutMs);
 
         if (originalCtxLoader != null) {
             Thread.currentThread().setContextClassLoader(originalCtxLoader);
@@ -441,4 +442,9 @@ public class PulsarAdminImpl implements PulsarAdmin {
 
         asyncHttpConnector.close();
     }
+
+    @VisibleForTesting
+     WebTarget getRoot() {
+        return root;
+    }
 }
