@@ -31,6 +31,7 @@ import org.apache.pulsar.client.admin.Schemas;
 import org.apache.pulsar.client.api.Authentication;
 import org.apache.pulsar.client.internal.DefaultImplementation;
 import org.apache.pulsar.common.naming.TopicName;
+import org.apache.pulsar.common.policies.data.SchemaMetadata;
 import org.apache.pulsar.common.protocol.schema.DeleteSchemaResponse;
 import org.apache.pulsar.common.protocol.schema.GetAllVersionsSchemaResponse;
 import org.apache.pulsar.common.protocol.schema.GetSchemaResponse;
@@ -276,6 +277,19 @@ public class SchemasImpl extends BaseResource implements Schemas {
                         .collect(Collectors.toList()));
     }
 
+    @Override
+    public SchemaMetadata getSchemaMetadata(String topic) throws PulsarAdminException {
+        return sync(() -> getSchemaMetadataAsync(topic));
+    }
+
+    @Override
+    public CompletableFuture<SchemaMetadata> getSchemaMetadataAsync(String topic) {
+        TopicName tn = TopicName.get(topic);
+        WebTarget path = metadata(tn);
+        return asyncGetRequest(path, new FutureCallback<SchemaMetadata>(){});
+    }
+
+
     private WebTarget schemaPath(TopicName topicName) {
         return topicPath(topicName, "schema");
     }
@@ -292,6 +306,10 @@ public class SchemasImpl extends BaseResource implements Schemas {
         return topicPath(topicName, "compatibility");
     }
 
+    private WebTarget metadata(TopicName topicName) {
+        return topicPath(topicName, "metadata");
+    }
+
     private WebTarget topicPath(TopicName topic, String... parts) {
         final WebTarget base = topic.isV2() ? adminV2 : adminV1;
         WebTarget topicPath = base.path(topic.getRestPath(false));
