@@ -18,32 +18,33 @@
  */
 package org.apache.pulsar.client.impl;
 
-import com.google.re2j.Pattern;
-import io.netty.channel.ChannelHandlerContext;
-import io.netty.util.HashedWheelTimer;
-import io.netty.util.Timer;
-import lombok.Cleanup;
-import org.apache.commons.lang3.tuple.Pair;
-import org.apache.pulsar.client.impl.PatternMultiTopicsConsumerImpl.TopicsChangedListener;
-import org.apache.pulsar.client.impl.conf.ClientConfigurationData;
-import org.apache.pulsar.common.api.proto.BaseCommand;
-import org.apache.pulsar.common.api.proto.CommandWatchTopicListSuccess;
-import org.apache.pulsar.common.api.proto.CommandWatchTopicUpdate;
-import org.apache.pulsar.common.naming.NamespaceName;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyCollection;
 import static org.mockito.ArgumentMatchers.anyInt;
 import static org.mockito.ArgumentMatchers.anyLong;
 import static org.mockito.ArgumentMatchers.anyString;
 import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 import static org.testng.Assert.assertTrue;
-import org.mockito.ArgumentCaptor;
-import org.testng.annotations.BeforeMethod;
-import org.testng.annotations.Test;
+import io.netty.channel.ChannelHandlerContext;
+import io.netty.util.HashedWheelTimer;
+import io.netty.util.Timer;
 import java.util.Collections;
 import java.util.concurrent.CompletableFuture;
+import java.util.regex.Pattern;
+import lombok.Cleanup;
+import org.apache.commons.lang3.tuple.Pair;
+import org.apache.pulsar.client.api.Consumer;
+import org.apache.pulsar.client.impl.PatternMultiTopicsConsumerImpl.TopicsChangedListener;
+import org.apache.pulsar.client.impl.conf.ClientConfigurationData;
+import org.apache.pulsar.common.api.proto.CommandWatchTopicListSuccess;
+import org.apache.pulsar.common.api.proto.CommandWatchTopicUpdate;
+import org.apache.pulsar.common.naming.NamespaceName;
+import org.apache.pulsar.common.topics.TopicsPatternFactory;
+import org.testng.annotations.BeforeMethod;
+import org.testng.annotations.Test;
 
 public class TopicListWatcherTest {
 
@@ -52,6 +53,7 @@ public class TopicListWatcherTest {
     private PulsarClientImpl client;
     private CompletableFuture<TopicListWatcher> watcherFuture;
     private TopicsChangedListener listener;
+    private PatternMultiTopicsConsumerImpl<byte[]> patternConsumer;
 
     @BeforeMethod(alwaysRun = true)
     public void setup() {
@@ -67,23 +69,29 @@ public class TopicListWatcherTest {
         Timer timer = new HashedWheelTimer();
         when(client.timer()).thenReturn(timer);
         String topic = "persistent://tenant/ns/topic\\d+";
-        when(client.getConnection(topic, 0)).
+        when(client.getConnection(anyString(), anyInt())).
                 thenReturn(clientCnxFuture.thenApply(clientCnx -> Pair.of(clientCnx, false)));
         when(client.getConnection(any(), any(), anyInt())).thenReturn(clientCnxFuture);
         when(connectionPool.getConnection(any(), any(), anyInt())).thenReturn(clientCnxFuture);
 
         CompletableFuture<Void> completedFuture = CompletableFuture.completedFuture(null);
-        PatternMultiTopicsConsumerImpl patternConsumer = mock(PatternMultiTopicsConsumerImpl.class);
-        when(patternConsumer.getSubscribeFuture()).thenReturn(completedFuture);
+        patternConsumer = mock(PatternMultiTopicsConsumerImpl.class);
+        when(patternConsumer.getPattern()).thenReturn(TopicsPatternFactory.create(Pattern.compile(topic)));
+        when(patternConsumer.getPartitions()).thenReturn(Collections.singletonList("persistent://tenant/ns/topic11"));
+        CompletableFuture<Consumer<byte[]>> subscribeFuture = CompletableFuture.completedFuture(patternConsumer);
+        when(patternConsumer.getSubscribeFuture()).thenReturn(subscribeFuture);
         when(patternConsumer.recheckTopicsChange()).thenReturn(completedFuture);
         when(listener.onTopicsAdded(anyCollection())).thenReturn(completedFuture);
         when(listener.onTopicsRemoved(anyCollection())).thenReturn(completedFuture);
+        when(patternConsumer.handleWatchTopicListSuccess(any(), any(), anyInt())).thenReturn(completedFuture);
+        when(patternConsumer.supportsTopicListWatcherReconcile()).thenReturn(true);
         PatternConsumerUpdateQueue queue = new PatternConsumerUpdateQueue(patternConsumer, listener);
 
         watcherFuture = new CompletableFuture<>();
         watcher = new TopicListWatcher(queue, client,
-                Pattern.compile(topic), 7,
-                NamespaceName.get("tenant/ns"), null, watcherFuture, () -> {});
+                TopicsPatternFactory.create(Pattern.compile(topic)), 7,
+                NamespaceName.get("tenant/ns"), patternConsumer::getLocalStateTopicsHash, watcherFuture,
+                () -> 0);
     }
 
     @Test
@@ -93,34 +101,44 @@ public class TopicListWatcherTest {
 
     @Test
     public void testWatcherCreatesBrokerSideObjectWhenConnected() {
-        ClientCnx clientCnx = mock(ClientCnx.class);
+        ClientCnx clientCnx = mockClientCnx();
         CompletableFuture<CommandWatchTopicListSuccess> responseFuture = new CompletableFuture<>();
-        ArgumentCaptor<BaseCommand> commandCaptor = ArgumentCaptor.forClass(BaseCommand.class);
-        when(clientCnx.newWatchTopicList(any(BaseCommand.class), anyLong())).thenReturn(responseFuture);
+        when(clientCnx.newWatchTopicList(anyLong(), anyLong(), anyString(), anyString(), any()))
+                .thenReturn(responseFuture);
         when(clientCnx.ctx()).thenReturn(mock(ChannelHandlerContext.class));
         clientCnxFuture.complete(clientCnx);
-        verify(clientCnx).newWatchTopicList(commandCaptor.capture(), anyLong());
+
+        verify(clientCnx).newWatchTopicList(anyLong(), anyLong(), anyString(), anyString(), any());
+
         CommandWatchTopicListSuccess success = new CommandWatchTopicListSuccess()
                 .setWatcherId(7)
-                .setRequestId(commandCaptor.getValue().getWatchTopicList().getRequestId())
+                .setRequestId(0)
                 .setTopicsHash("FEED");
         success.addTopic("persistent://tenant/ns/topic11");
         responseFuture.complete(success);
         assertTrue(watcherFuture.isDone() && !watcherFuture.isCompletedExceptionally());
     }
 
+    private static ClientCnx mockClientCnx() {
+        ClientCnx clientCnx = mock(ClientCnx.class);
+        when(clientCnx.isSupportsTopicWatchers()).thenReturn(true);
+        when(clientCnx.isSupportsTopicWatcherReconcile()).thenReturn(true);
+        return clientCnx;
+    }
+
     @Test
     public void testWatcherCallsListenerOnUpdate() {
-        ClientCnx clientCnx = mock(ClientCnx.class);
+        ClientCnx clientCnx = mockClientCnx();
         CompletableFuture<CommandWatchTopicListSuccess> responseFuture = new CompletableFuture<>();
-        ArgumentCaptor<BaseCommand> commandCaptor = ArgumentCaptor.forClass(BaseCommand.class);
-        when(clientCnx.newWatchTopicList(any(BaseCommand.class), anyLong())).thenReturn(responseFuture);
+        when(clientCnx.newWatchTopicList(anyLong(), anyLong(), anyString(), anyString(), any()))
+                .thenReturn(responseFuture);
         when(clientCnx.ctx()).thenReturn(mock(ChannelHandlerContext.class));
         clientCnxFuture.complete(clientCnx);
-        verify(clientCnx).newWatchTopicList(commandCaptor.capture(), anyLong());
+        verify(clientCnx).newWatchTopicList(anyLong(), anyLong(), anyString(), anyString(), any());
+
         CommandWatchTopicListSuccess success = new CommandWatchTopicListSuccess()
                 .setWatcherId(7)
-                .setRequestId(commandCaptor.getValue().getWatchTopicList().getRequestId())
+                .setRequestId(0)
                 .setTopicsHash("FEED");
         success.addTopic("persistent://tenant/ns/topic11");
         responseFuture.complete(success);
@@ -133,4 +151,38 @@ public class TopicListWatcherTest {
         watcher.handleCommandWatchTopicUpdate(update);
         verify(listener).onTopicsAdded(Collections.singletonList("persistent://tenant/ns/topic12"));
     }
+
+    @Test
+    public void testWatcherTriggersReconciliationOnHashMismatch() {
+        ClientCnx clientCnx = mockClientCnx();
+
+        CompletableFuture<CommandWatchTopicListSuccess> responseFuture = new CompletableFuture<>();
+        when(clientCnx.newWatchTopicList(anyLong(), anyLong(), anyString(), anyString(), any()))
+                .thenReturn(responseFuture);
+        when(clientCnx.ctx()).thenReturn(mock(ChannelHandlerContext.class));
+        clientCnxFuture.complete(clientCnx);
+
+        CommandWatchTopicListSuccess success = new CommandWatchTopicListSuccess()
+                .setWatcherId(7)
+                .setRequestId(0)
+                .setTopicsHash("FEED");
+        success.addTopic("persistent://tenant/ns/topic11");
+        responseFuture.complete(success);
+
+        // verify that the response was handled
+        verify(patternConsumer, times(1)).handleWatchTopicListSuccess(any(), any(), anyInt());
+        // sync local hash
+        when(patternConsumer.getLocalStateTopicsHash()).thenReturn("FEED");
+
+        // Send update with a mismatching hash
+        CommandWatchTopicUpdate update = new CommandWatchTopicUpdate()
+                .setTopicsHash("WRONG_HASH")
+                .setWatcherId(7)
+                .addAllNewTopics(Collections.singleton("persistent://tenant/ns/topic12"));
+
+        watcher.handleCommandWatchTopicUpdate(update);
+
+        // Verify that reconciliation was triggered again due to hash mismatch
+        verify(patternConsumer, times(1)).recheckTopicsChange();
+    }
 }
