@@ -23,7 +23,6 @@ import static org.testng.Assert.assertEquals;
 import static org.testng.Assert.assertNull;
 import static org.testng.Assert.assertTrue;
 import static org.testng.AssertJUnit.assertSame;
-
 import com.fasterxml.jackson.core.JsonProcessingException;
 import com.fasterxml.jackson.databind.JsonNode;
 import com.fasterxml.jackson.databind.ObjectMapper;
@@ -39,14 +38,13 @@ import org.apache.pulsar.common.schema.SchemaType;
 import org.apache.pulsar.common.util.ObjectMapperFactory;
 import org.testng.annotations.Test;
 
-
 public class GenericJsonRecordTest {
 
     @Test
     public void decodeNullValue() throws Exception{
         byte[] json = "{\"somefield\":null}".getBytes(UTF_8);
-        GenericJsonRecord record
-                = new GenericJsonReader(Collections.singletonList(new Field("somefield", 0)))
+        GenericJsonRecord record =
+                new GenericJsonReader(Collections.singletonList(new Field("somefield", 0)))
                         .read(json, 0, json.length);
         assertTrue(record.getJsonNode().get("somefield").isNull());
         assertNull(record.getField("somefield"));
@@ -74,7 +72,7 @@ public class GenericJsonRecordTest {
         assertEquals(1.1, value);
 
         Object boolValue = record.getField("on");
-        assertTrue((boolean)boolValue);
+        assertTrue((boolean) boolValue);
     }
 
     @Data
@@ -119,8 +117,8 @@ public class GenericJsonRecordTest {
     @Test
     public void testGetNativeRecord() throws Exception{
         byte[] json = "{\"somefield\":null}".getBytes(UTF_8);
-        GenericJsonRecord record
-                = new GenericJsonReader(Collections.singletonList(new Field("somefield", 0)))
+        GenericJsonRecord record =
+                new GenericJsonReader(Collections.singletonList(new Field("somefield", 0)))
                 .read(json, 0, json.length);
         assertEquals(SchemaType.JSON, record.getSchemaType());
         assertSame(record.getNativeObject(), record.getJsonNode());
