@@ -39,10 +39,10 @@ import java.util.function.Supplier;
 import lombok.Getter;
 import lombok.extern.slf4j.Slf4j;
 import org.apache.bookkeeper.common.concurrent.FutureUtils;
+import org.apache.bookkeeper.common.util.OrderedExecutor;
 import org.apache.pulsar.common.stats.CacheMetricsCollector;
 import org.apache.pulsar.common.util.Backoff;
 import org.apache.pulsar.metadata.api.CacheGetResult;
-import org.apache.pulsar.metadata.api.GetResult;
 import org.apache.pulsar.metadata.api.MetadataCache;
 import org.apache.pulsar.metadata.api.MetadataCacheConfig;
 import org.apache.pulsar.metadata.api.MetadataSerde;
@@ -62,23 +62,26 @@ public class MetadataCacheImpl<T> implements MetadataCache<T>, Consumer<Notifica
     private final MetadataStore store;
     private final MetadataStoreExtended storeExtended;
     private final MetadataSerde<T> serde;
-    private final ScheduledExecutorService executor;
+    private final OrderedExecutor executor;
+    private final ScheduledExecutorService schedulerExecutor;
     private final MetadataCacheConfig<T> cacheConfig;
 
     private final AsyncLoadingCache<String, Optional<CacheGetResult<T>>> objCache;
 
     public MetadataCacheImpl(String cacheName, MetadataStore store, TypeReference<T> typeRef,
-                             MetadataCacheConfig<T> cacheConfig, ScheduledExecutorService executor) {
-        this(cacheName, store, new JSONMetadataSerdeTypeRef<>(typeRef), cacheConfig, executor);
+                             MetadataCacheConfig<T> cacheConfig, OrderedExecutor executor,
+                             ScheduledExecutorService schedulerExecutor) {
+        this(cacheName, store, new JSONMetadataSerdeTypeRef<>(typeRef), cacheConfig, executor, schedulerExecutor);
     }
 
     public MetadataCacheImpl(String cacheName, MetadataStore store, JavaType type, MetadataCacheConfig<T> cacheConfig,
-                             ScheduledExecutorService executor) {
-        this(cacheName, store, new JSONMetadataSerdeSimpleType<>(type), cacheConfig, executor);
+                             OrderedExecutor executor, ScheduledExecutorService schedulerExecutor) {
+        this(cacheName, store, new JSONMetadataSerdeSimpleType<>(type), cacheConfig, executor, schedulerExecutor);
     }
 
     public MetadataCacheImpl(String cacheName, MetadataStore store, MetadataSerde<T> serde,
-                             MetadataCacheConfig<T> cacheConfig, ScheduledExecutorService executor) {
+                             MetadataCacheConfig<T> cacheConfig, OrderedExecutor executor,
+                             ScheduledExecutorService schedulerExecutor) {
         this.store = store;
         if (store instanceof MetadataStoreExtended) {
             this.storeExtended = (MetadataStoreExtended) store;
@@ -88,6 +91,7 @@ public class MetadataCacheImpl<T> implements MetadataCache<T>, Consumer<Notifica
         this.serde = serde;
         this.cacheConfig = cacheConfig;
         this.executor = executor;
+        this.schedulerExecutor = schedulerExecutor;
 
         Caffeine<Object, Object> cacheBuilder = Caffeine.newBuilder();
         if (cacheConfig.getRefreshAfterWriteMillis() > 0) {
@@ -101,6 +105,9 @@ public class MetadataCacheImpl<T> implements MetadataCache<T>, Consumer<Notifica
                 .buildAsync(new AsyncCacheLoader<String, Optional<CacheGetResult<T>>>() {
                     @Override
                     public CompletableFuture<Optional<CacheGetResult<T>>> asyncLoad(String key, Executor executor) {
+                        if (log.isDebugEnabled()) {
+                            log.debug("Loading key {} into metadata cache {}", key, cacheName);
+                        }
                         return readValueFromStore(key);
                     }
 
@@ -110,12 +117,16 @@ public class MetadataCacheImpl<T> implements MetadataCache<T>, Consumer<Notifica
                             Optional<CacheGetResult<T>> oldValue,
                             Executor executor) {
                         if (store instanceof AbstractMetadataStore && ((AbstractMetadataStore) store).isConnected()) {
-                            return readValueFromStore(key).thenApply(val -> {
+                            if (log.isDebugEnabled()) {
+                                log.debug("Reloading key {} into metadata cache {}", key, cacheName);
+                            }
+                            final var future = readValueFromStore(key);
+                            future.thenAccept(val -> {
                                 if (cacheConfig.getAsyncReloadConsumer() != null) {
                                     cacheConfig.getAsyncReloadConsumer().accept(key, val);
                                 }
-                                return val;
                             });
+                            return future;
                         } else {
                             // Do not try to refresh the cache item if we know that we're not connected to the
                             // metadata store
@@ -128,22 +139,39 @@ public class MetadataCacheImpl<T> implements MetadataCache<T>, Consumer<Notifica
     }
 
     private CompletableFuture<Optional<CacheGetResult<T>>> readValueFromStore(String path) {
-        return store.get(path)
-                .thenCompose(optRes -> {
-                    if (!optRes.isPresent()) {
-                        return FutureUtils.value(Optional.empty());
-                    }
-
-                    try {
-                        GetResult res = optRes.get();
-                        T obj = serde.deserialize(path, res.getValue(), res.getStat());
-                        return FutureUtils
-                                .value(Optional.of(new CacheGetResult<>(obj, res.getStat())));
-                    } catch (Throwable t) {
-                        return FutureUtils.exception(new ContentDeserializationException(
-                                "Failed to deserialize payload for key '" + path + "'", t));
-                    }
-                });
+        final var future = new CompletableFuture<Optional<CacheGetResult<T>>>();
+        store.get(path).thenComposeAsync(optRes -> {
+            // There could be multiple pending reads for the same path, for example, when a path is created,
+            // 1. The `accept` method will call `refresh`
+            // 2. The `put` method will call `refresh` after the metadata store put operation is done
+            // Both will call this method and the same result will be read. In this case, we only need to deserialize
+            // the value once.
+            if (!optRes.isPresent()) {
+                if (log.isDebugEnabled()) {
+                    log.debug("Key {} not found in metadata store", path);
+                }
+                return FutureUtils.value(Optional.<CacheGetResult<T>>empty());
+            }
+            final var res = optRes.get();
+            try {
+                T obj = serde.deserialize(path, res.getValue(), res.getStat());
+                if (log.isDebugEnabled()) {
+                    log.debug("Deserialized value for key {} (version: {}): {}", path, res.getStat().getVersion(),
+                        obj);
+                }
+                return FutureUtils.value(Optional.of(new CacheGetResult<>(obj, res.getStat())));
+            } catch (Throwable t) {
+                return FutureUtils.exception(new ContentDeserializationException(
+                    "Failed to deserialize payload for key '" + path + "'", t));
+            }
+        }, executor.chooseThread(path)).whenComplete((result, e) -> {
+            if (e != null) {
+                future.completeExceptionally(e.getCause());
+            } else {
+                future.complete(result);
+            }
+        });
+        return future;
     }
 
     @Override
@@ -169,8 +197,9 @@ public class MetadataCacheImpl<T> implements MetadataCache<T>, Consumer<Notifica
 
     @Override
     public CompletableFuture<T> readModifyUpdateOrCreate(String path, Function<Optional<T>, T> modifyFunction) {
+        final var executor = this.executor.chooseThread(path);
         return executeWithRetry(() -> objCache.get(path)
-                .thenCompose(optEntry -> {
+                .thenComposeAsync(optEntry -> {
                     Optional<T> currentValue;
                     long expectedVersion;
 
@@ -202,13 +231,14 @@ public class MetadataCacheImpl<T> implements MetadataCache<T>, Consumer<Notifica
                     return store.put(path, newValue, Optional.of(expectedVersion)).thenAccept(__ -> {
                         refresh(path);
                     }).thenApply(__ -> newValueObj);
-                }), path);
+                }, executor), path);
     }
 
     @Override
     public CompletableFuture<T> readModifyUpdate(String path, Function<T, T> modifyFunction) {
+        final var executor = this.executor.chooseThread(path);
         return executeWithRetry(() -> objCache.get(path)
-                .thenCompose(optEntry -> {
+                .thenComposeAsync(optEntry -> {
                     if (!optEntry.isPresent()) {
                         return FutureUtils.exception(new NotFoundException(""));
                     }
@@ -231,59 +261,57 @@ public class MetadataCacheImpl<T> implements MetadataCache<T>, Consumer<Notifica
                     return store.put(path, newValue, Optional.of(expectedVersion)).thenAccept(__ -> {
                         refresh(path);
                     }).thenApply(__ -> newValueObj);
-                }), path);
+                }, executor), path);
+    }
+
+    private CompletableFuture<byte[]> serialize(String path, T value) {
+        final var future = new CompletableFuture<byte[]>();
+        executor.executeOrdered(path, () -> {
+            try {
+                future.complete(serde.serialize(path, value));
+            } catch (Throwable t) {
+                future.completeExceptionally(t);
+            }
+        });
+        return future;
     }
 
     @Override
     public CompletableFuture<Void> create(String path, T value) {
-        byte[] content;
-        try {
-            content = serde.serialize(path, value);
-        } catch (Throwable t) {
-            return FutureUtils.exception(t);
-        }
-
-        CompletableFuture<Void> future = new CompletableFuture<>();
-        store.put(path, content, Optional.of(-1L))
-                .thenAccept(stat -> {
-                    // Make sure we have the value cached before the operation is completed
-                    // In addition to caching the value, we need to add a watch on the path,
-                    // so when/if it changes on any other node, we are notified and we can
-                    // update the cache
-                    objCache.get(path).whenComplete((stat2, ex) -> {
-                        if (ex == null) {
-                            future.complete(null);
-                        } else {
-                            log.error("Exception while getting path {}", path, ex);
-                            future.completeExceptionally(ex.getCause());
-                        }
-                    });
-                }).exceptionally(ex -> {
-                    if (ex.getCause() instanceof BadVersionException) {
-                        // Use already exists exception to provide more self-explanatory error message
-                        future.completeExceptionally(new AlreadyExistsException(ex.getCause()));
-                    } else {
-                        future.completeExceptionally(ex.getCause());
-                    }
-                    return null;
-                });
-
+        final var future = new CompletableFuture<Void>();
+        serialize(path, value).thenCompose(content -> store.put(path, content, Optional.of(-1L)))
+            // Make sure we have the value cached before the operation is completed
+            // In addition to caching the value, we need to add a watch on the path,
+            // so when/if it changes on any other node, we are notified and we can
+            // update the cache
+            .thenCompose(__ -> objCache.get(path))
+            .whenComplete((__, ex) -> {
+                if (ex == null) {
+                    future.complete(null);
+                } else if (ex.getCause() instanceof BadVersionException) {
+                    // Use already exists exception to provide more self-explanatory error message
+                    future.completeExceptionally(new AlreadyExistsException(ex.getCause()));
+                } else {
+                    future.completeExceptionally(ex.getCause());
+                }
+            });
         return future;
     }
 
     @Override
     public CompletableFuture<Void> put(String path, T value, EnumSet<CreateOption> options) {
-        final byte[] bytes;
-        try {
-            bytes = serde.serialize(path, value);
-        } catch (IOException e) {
-            return CompletableFuture.failedFuture(e);
-        }
-        if (storeExtended != null) {
-            return storeExtended.put(path, bytes, Optional.empty(), options).thenAccept(__ -> refresh(path));
-        } else {
-            return store.put(path, bytes, Optional.empty()).thenAccept(__ -> refresh(path));
-        }
+        return serialize(path, value).thenCompose(bytes -> {
+            if (storeExtended != null) {
+                return storeExtended.put(path, bytes, Optional.empty(), options);
+            } else {
+                return store.put(path, bytes, Optional.empty());
+            }
+        }).thenAccept(__ -> {
+            if (log.isDebugEnabled()) {
+                log.debug("Refreshing path {} after put operation", path);
+            }
+            refresh(path);
+        });
     }
 
     @Override
@@ -323,6 +351,9 @@ public class MetadataCacheImpl<T> implements MetadataCache<T>, Consumer<Notifica
         switch (t.getType()) {
         case Created:
         case Modified:
+            if (log.isDebugEnabled()) {
+                log.debug("Refreshing path {} for {} notification", path, t.getType());
+            }
             refresh(path);
             break;
 
@@ -354,8 +385,7 @@ public class MetadataCacheImpl<T> implements MetadataCache<T>, Consumer<Notifica
                 final var next = backoff.next();
                 log.info("Update key {} conflicts. Retrying in {} ms. Mandatory stop: {}. Elapsed time: {} ms", key,
                         next, backoff.isMandatoryStopMade(), elapsed);
-                executor.schedule(() -> execute(op, key, result, backoff), next,
-                        TimeUnit.MILLISECONDS);
+                schedulerExecutor.schedule(() -> execute(op, key, result, backoff), next, TimeUnit.MILLISECONDS);
                 return null;
             }
             result.completeExceptionally(ex.getCause());
