@@ -21,12 +21,14 @@ package org.apache.pulsar.opentelemetry;
 import static com.google.common.base.Preconditions.checkArgument;
 import com.google.common.annotations.VisibleForTesting;
 import io.opentelemetry.api.OpenTelemetry;
+import io.opentelemetry.exporter.prometheus.PrometheusHttpServer;
 import io.opentelemetry.instrumentation.runtimemetrics.java17.RuntimeMetrics;
 import io.opentelemetry.sdk.OpenTelemetrySdk;
 import io.opentelemetry.sdk.autoconfigure.AutoConfiguredOpenTelemetrySdk;
 import io.opentelemetry.sdk.autoconfigure.AutoConfiguredOpenTelemetrySdkBuilder;
+import io.opentelemetry.sdk.common.export.MemoryMode;
 import io.opentelemetry.sdk.resources.Resource;
-import io.opentelemetry.semconv.ResourceAttributes;
+import io.opentelemetry.semconv.ServiceAttributes;
 import java.io.Closeable;
 import java.util.Map;
 import java.util.Objects;
@@ -72,7 +74,9 @@ public class OpenTelemetryService implements Closeable {
         sdkBuilder.addPropertiesSupplier(() -> Map.of(
                 OTEL_SDK_DISABLED_KEY, "true",
                 // Cardinality limit includes the overflow attribute set, so we need to add 1.
-                "otel.experimental.metrics.cardinality.limit", Integer.toString(MAX_CARDINALITY_LIMIT + 1)
+                "otel.java.metrics.cardinality.limit", Integer.toString(MAX_CARDINALITY_LIMIT + 1),
+                // Reduce number of allocations by using reusable data mode.
+                "otel.java.exporter.memory_mode", MemoryMode.REUSABLE_DATA.name()
         ));
 
         sdkBuilder.addResourceCustomizer(
@@ -83,17 +87,31 @@ public class OpenTelemetryService implements Closeable {
                         resourceBuilder.put(OpenTelemetryAttributes.PULSAR_CLUSTER, clusterName);
                     }
                     if (StringUtils.isNotBlank(serviceName)
-                            && Objects.equals(Resource.getDefault().getAttribute(ResourceAttributes.SERVICE_NAME),
-                                              resource.getAttribute(ResourceAttributes.SERVICE_NAME))) {
-                        resourceBuilder.put(ResourceAttributes.SERVICE_NAME, serviceName);
+                            && Objects.equals(Resource.getDefault().getAttribute(ServiceAttributes.SERVICE_NAME),
+                                              resource.getAttribute(ServiceAttributes.SERVICE_NAME))) {
+                        resourceBuilder.put(ServiceAttributes.SERVICE_NAME, serviceName);
                     }
                     if (StringUtils.isNotBlank(serviceVersion)
-                            && resource.getAttribute(ResourceAttributes.SERVICE_VERSION) == null) {
-                        resourceBuilder.put(ResourceAttributes.SERVICE_VERSION, serviceVersion);
+                            && resource.getAttribute(ServiceAttributes.SERVICE_VERSION) == null) {
+                        resourceBuilder.put(ServiceAttributes.SERVICE_VERSION, serviceVersion);
                     }
                     return resource.merge(resourceBuilder.build());
                 });
 
+        sdkBuilder.addMetricReaderCustomizer((metricReader, configProperties) -> {
+            if (metricReader instanceof PrometheusHttpServer prometheusHttpServer) {
+                // At this point, the server is already started. We need to close it and create a new one with the
+                // correct resource attributes filter.
+                prometheusHttpServer.close();
+
+                // Allow all resource attributes to be exposed.
+                return prometheusHttpServer.toBuilder()
+                        .setAllowedResourceAttributesFilter(s -> true)
+                        .build();
+            }
+            return metricReader;
+        });
+
         if (builderCustomizer != null) {
             builderCustomizer.accept(sdkBuilder);
         }
@@ -105,7 +123,7 @@ public class OpenTelemetryService implements Closeable {
                 // disable JFR based telemetry and use only JMX telemetry
                 .disableAllFeatures()
                 // enable experimental JMX telemetry in addition
-                .enableExperimentalJmxTelemetry()
+                .emitExperimentalTelemetry()
                 .build());
     }
 
