@@ -34,7 +34,6 @@ import io.netty.channel.epoll.EpollChannelOption;
 import io.netty.channel.epoll.EpollMode;
 import io.netty.channel.epoll.EpollSocketChannel;
 import io.netty.channel.socket.SocketChannel;
-import io.netty.handler.codec.LengthFieldBasedFrameDecoder;
 import io.netty.handler.codec.haproxy.HAProxyCommand;
 import io.netty.handler.codec.haproxy.HAProxyMessage;
 import io.netty.handler.codec.haproxy.HAProxyProtocolVersion;
@@ -56,10 +55,12 @@ import org.apache.pulsar.client.api.AuthenticationDataProvider;
 import org.apache.pulsar.client.api.PulsarClientException;
 import org.apache.pulsar.common.allocator.PulsarByteBufAllocator;
 import org.apache.pulsar.common.api.AuthData;
+import org.apache.pulsar.common.api.proto.BaseCommand;
 import org.apache.pulsar.common.api.proto.CommandAuthChallenge;
 import org.apache.pulsar.common.api.proto.CommandConnected;
 import org.apache.pulsar.common.api.proto.FeatureFlags;
 import org.apache.pulsar.common.protocol.Commands;
+import org.apache.pulsar.common.protocol.FrameDecoderUtil;
 import org.apache.pulsar.common.protocol.PulsarDecoder;
 import org.apache.pulsar.common.stats.Rate;
 import org.apache.pulsar.common.util.PulsarSslConfiguration;
@@ -180,9 +181,7 @@ public class DirectProxyHandler {
                     ch.pipeline().addLast("readTimeoutHandler",
                             new ReadTimeoutHandler(brokerProxyReadTimeoutMs, TimeUnit.MILLISECONDS));
                 }
-                ch.pipeline().addLast("frameDecoder", new LengthFieldBasedFrameDecoder(
-                        service.getConfiguration().getMaxMessageSize() + Commands.MESSAGE_SIZE_FRAME_PADDING, 0, 4, 0,
-                        4));
+                FrameDecoderUtil.addFrameDecoder(ch.pipeline(), service.getConfiguration().getMaxMessageSize());
                 ch.pipeline().addLast("proxyOutboundHandler",
                         (ChannelHandler) new ProxyBackendHandler(config, protocolVersion, remoteHost, featureFlags));
             }
@@ -397,7 +396,7 @@ public class DirectProxyHandler {
         }
 
         @Override
-        protected void messageReceived() {
+        protected void messageReceived(BaseCommand cmd) {
             // no-op
         }
 
@@ -422,38 +421,32 @@ public class DirectProxyHandler {
                     log.debug("[{}] [{}] Removing decoder from pipeline", inboundChannel, outboundChannel);
                 }
                 // direct tcp proxy
-                inboundChannel.pipeline().remove("frameDecoder");
-                outboundChannel.pipeline().remove("frameDecoder");
+                FrameDecoderUtil.removeFrameDecoder(inboundChannel.pipeline());
+                FrameDecoderUtil.removeFrameDecoder(outboundChannel.pipeline());
             } else {
                 // Enable parsing feature, proxyLogLevel(1 or 2)
                 // Add parser handler
+                ParserProxyHandler.Context parserContext = ParserProxyHandler.createContext();
                 if (connected.hasMaxMessageSize()) {
-                    inboundChannel.pipeline()
-                            .replace("frameDecoder", "newFrameDecoder",
-                                    new LengthFieldBasedFrameDecoder(connected.getMaxMessageSize()
-                                            + Commands.MESSAGE_SIZE_FRAME_PADDING,
-                                            0, 4, 0, 4));
-                    outboundChannel.pipeline().replace("frameDecoder", "newFrameDecoder",
-                            new LengthFieldBasedFrameDecoder(
-                                    connected.getMaxMessageSize()
-                                            + Commands.MESSAGE_SIZE_FRAME_PADDING,
-                                    0, 4, 0, 4));
-
+                    FrameDecoderUtil.replaceFrameDecoder(inboundChannel.pipeline(),
+                            connected.getMaxMessageSize());
+                    FrameDecoderUtil.replaceFrameDecoder(outboundChannel.pipeline(),
+                            connected.getMaxMessageSize());
                     inboundChannel.pipeline().addBefore("handler", "inboundParser",
-                            new ParserProxyHandler(service,
+                            new ParserProxyHandler(parserContext, service,
                                     ParserProxyHandler.FRONTEND_CONN,
                                     connected.getMaxMessageSize(), outboundChannel.id()));
                     outboundChannel.pipeline().addBefore("proxyOutboundHandler", "outboundParser",
-                            new ParserProxyHandler(service,
+                            new ParserProxyHandler(parserContext, service,
                                     ParserProxyHandler.BACKEND_CONN,
                                     connected.getMaxMessageSize(), inboundChannel.id()));
                 } else {
                     inboundChannel.pipeline().addBefore("handler", "inboundParser",
-                            new ParserProxyHandler(service,
+                            new ParserProxyHandler(parserContext, service,
                                     ParserProxyHandler.FRONTEND_CONN,
                                     Commands.DEFAULT_MAX_MESSAGE_SIZE, outboundChannel.id()));
                     outboundChannel.pipeline().addBefore("proxyOutboundHandler", "outboundParser",
-                            new ParserProxyHandler(service,
+                            new ParserProxyHandler(parserContext, service,
                                     ParserProxyHandler.BACKEND_CONN,
                                     Commands.DEFAULT_MAX_MESSAGE_SIZE, inboundChannel.id()));
                 }
