@@ -18,6 +18,7 @@
  */
 package org.apache.pulsar.proxy.server;
 
+import static org.apache.pulsar.common.semaphore.AsyncDualMemoryLimiterUtil.acquireDirectMemoryPermitsAndWriteAndFlush;
 import io.netty.buffer.ByteBuf;
 import io.netty.channel.ChannelHandlerContext;
 import io.prometheus.client.Counter;
@@ -26,20 +27,29 @@ import java.net.SocketAddress;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.util.Optional;
+import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.Semaphore;
+import java.util.function.BooleanSupplier;
 import org.apache.commons.lang3.StringUtils;
+import org.apache.pulsar.broker.topiclistlimit.TopicListMemoryLimiter;
+import org.apache.pulsar.broker.topiclistlimit.TopicListSizeResultCache;
 import org.apache.pulsar.client.api.PulsarClientException;
 import org.apache.pulsar.client.impl.BinaryProtoLookupService;
+import org.apache.pulsar.client.impl.ClientCnx;
+import org.apache.pulsar.common.api.proto.BaseCommand;
 import org.apache.pulsar.common.api.proto.CommandGetSchema;
 import org.apache.pulsar.common.api.proto.CommandGetTopicsOfNamespace;
 import org.apache.pulsar.common.api.proto.CommandLookupTopic;
 import org.apache.pulsar.common.api.proto.CommandLookupTopicResponse.LookupType;
 import org.apache.pulsar.common.api.proto.CommandPartitionedTopicMetadata;
 import org.apache.pulsar.common.api.proto.ServerError;
+import org.apache.pulsar.common.lookup.GetTopicsResult;
 import org.apache.pulsar.common.naming.TopicName;
 import org.apache.pulsar.common.protocol.Commands;
 import org.apache.pulsar.common.protocol.schema.BytesSchemaVersion;
 import org.apache.pulsar.common.protocol.schema.SchemaVersion;
+import org.apache.pulsar.common.semaphore.AsyncDualMemoryLimiter;
+import org.apache.pulsar.common.semaphore.AsyncDualMemoryLimiterImpl;
 import org.apache.pulsar.common.util.netty.NettyChannelUtil;
 import org.apache.pulsar.policies.data.loadbalancer.ServiceLookupData;
 import org.slf4j.Logger;
@@ -84,6 +94,8 @@ public class LookupProxyHandler {
                     "Counter of getTopicsOfNamespace requests rejected due to throttling")
             .create().register();
     private final Semaphore lookupRequestSemaphore;
+    private final AsyncDualMemoryLimiterImpl maxTopicListInFlightLimiter;
+    private final TopicListSizeResultCache topicListSizeResultCache;
 
     public LookupProxyHandler(ProxyService proxy, ProxyConnection proxyConnection) {
         this.discoveryProvider = proxy.getDiscoveryProvider();
@@ -93,6 +105,8 @@ public class LookupProxyHandler {
         this.connectWithTLS = proxy.getConfiguration().isTlsEnabledWithBroker();
         this.brokerServiceURL = this.connectWithTLS ? proxy.getConfiguration().getBrokerServiceURLTLS()
                 : proxy.getConfiguration().getBrokerServiceURL();
+        this.maxTopicListInFlightLimiter = proxy.getMaxTopicListInFlightLimiter();
+        this.topicListSizeResultCache = proxy.getTopicListSizeResultCache();
     }
 
     public void handleLookup(CommandLookupTopic lookup) {
@@ -221,7 +235,7 @@ public class LookupProxyHandler {
      **/
     private void handlePartitionMetadataResponse(CommandPartitionedTopicMetadata partitionMetadata,
             long clientRequestId) {
-        TopicName topicName = TopicName.get(partitionMetadata.getTopic());
+        String topicName = TopicName.toFullTopicName(partitionMetadata.getTopic());
 
         String serviceUrl = getBrokerServiceUrl(clientRequestId);
         if (serviceUrl == null) {
@@ -235,7 +249,7 @@ public class LookupProxyHandler {
 
         if (log.isDebugEnabled()) {
             log.debug("Getting connections to '{}' for Looking up topic '{}' with clientReq Id '{}'", addr,
-                    topicName.getPartitionedTopicName(), clientRequestId);
+                    topicName, clientRequestId);
         }
         proxyConnection.getConnectionPool().getConnection(addr).thenAccept(clientCnx -> {
             // Connected to backend broker
@@ -245,10 +259,11 @@ public class LookupProxyHandler {
                     partitionMetadata.isMetadataAutoCreationEnabled());
             clientCnx.newLookup(command, requestId).whenComplete((r, t) -> {
                 if (t != null) {
-                    log.warn("[{}] failed to get Partitioned metadata : {}", topicName.toString(),
+                    log.warn("[{}] failed to get Partitioned metadata : {}", topicName,
                         t.getMessage(), t);
-                    writeAndFlush(Commands.newLookupErrorResponse(getServerError(t),
-                        t.getMessage(), clientRequestId));
+                    PulsarClientException pce = PulsarClientException.unwrap(t);
+                    writeAndFlush(Commands.newLookupErrorResponse(clientCnx.revertClientExToErrorCode(pce),
+                            t.getMessage(), clientRequestId));
                 } else {
                     writeAndFlush(
                         Commands.newPartitionMetadataResponse(r.partitions, clientRequestId));
@@ -325,7 +340,7 @@ public class LookupProxyHandler {
 
         if (log.isDebugEnabled()) {
             log.debug("Getting connections to '{}' for getting TopicsOfNamespace '{}' with clientReq Id '{}'",
-                addr, namespaceName, clientRequestId);
+                    addr, namespaceName, clientRequestId);
         }
         proxyConnection.getConnectionPool().getConnection(addr).thenAccept(clientCnx -> {
             // Connected to backend broker
@@ -333,20 +348,8 @@ public class LookupProxyHandler {
             ByteBuf command;
             command = Commands.newGetTopicsOfNamespaceRequest(namespaceName, requestId, mode,
                     topicsPattern, topicsHash);
-            clientCnx.newGetTopicsOfNamespace(command, requestId).whenComplete((r, t) -> {
-                if (t != null) {
-                    log.warn("[{}] Failed to get TopicsOfNamespace {}: {}",
-                            clientAddress, namespaceName, t.getMessage());
-                    writeAndFlush(
-                        Commands.newError(clientRequestId, getServerError(t), t.getMessage()));
-                } else {
-                    writeAndFlush(
-                        Commands.newGetTopicsOfNamespaceResponse(r.getNonPartitionedOrPartitionTopics(),
-                                r.getTopicsHash(), r.isFiltered(),
-                                r.isChanged(), clientRequestId));
-                }
-            });
 
+            internalPerformGetTopicsOfNamespace(clientRequestId, namespaceName, mode, clientCnx, command, requestId);
             proxyConnection.getConnectionPool().releaseConnection(clientCnx);
         }).exceptionally(ex -> {
             // Failed to connect to backend broker
@@ -356,6 +359,72 @@ public class LookupProxyHandler {
         });
     }
 
+    private void internalPerformGetTopicsOfNamespace(long clientRequestId, String namespaceName,
+                                                     CommandGetTopicsOfNamespace.Mode mode, ClientCnx clientCnx,
+                                                     ByteBuf command, long requestId) {
+        BooleanSupplier isPermitRequestCancelled = () -> !proxyConnection.ctx().channel().isActive();
+        TopicListSizeResultCache.ResultHolder
+                listSizeHolder = topicListSizeResultCache.getTopicListSize(namespaceName, mode);
+        listSizeHolder.getSizeAsync().thenAccept(initialSize -> {
+            maxTopicListInFlightLimiter.withAcquiredPermits(initialSize,
+                    AsyncDualMemoryLimiter.LimitType.HEAP_MEMORY, isPermitRequestCancelled, initialPermits -> {
+                        return clientCnx.newGetTopicsOfNamespace(command, requestId).handle((r, t) -> {
+                            if (t != null) {
+                                log.warn("[{}] Failed to get TopicsOfNamespace {}: {}", clientAddress, namespaceName,
+                                        t.getMessage());
+                                listSizeHolder.resetIfInitializing();
+                                writeAndFlush(Commands.newError(clientRequestId, getServerError(t), t.getMessage()));
+                                return CompletableFuture.completedFuture(null);
+                            } else {
+                                long actualSize = TopicListMemoryLimiter.estimateTopicListSize(
+                                        r.getNonPartitionedOrPartitionTopics());
+                                listSizeHolder.updateSize(actualSize);
+                                return maxTopicListInFlightLimiter.withUpdatedPermits(initialPermits, actualSize,
+                                        isPermitRequestCancelled, permits -> {
+                                            return handleWritingGetTopicsResponse(clientRequestId, r,
+                                                    isPermitRequestCancelled);
+                                        }, t2 -> {
+                                            log.warn("[{}] Failed to acquire actual heap memory permits for "
+                                                    + "GetTopicsOfNamespace: {}", clientAddress, t2.getMessage());
+                                            writeAndFlush(
+                                                    Commands.newError(clientRequestId, ServerError.TooManyRequests,
+                                                            "Failed due to heap memory limit exceeded"));
+
+                                            return CompletableFuture.completedFuture(null);
+                                        });
+                            }
+                        });
+                    }, t -> {
+                        log.warn("[{}] Failed to acquire initial heap memory permits for GetTopicsOfNamespace: {}",
+                                clientAddress, t.getMessage());
+                        listSizeHolder.resetIfInitializing();
+                        writeAndFlush(Commands.newError(clientRequestId, ServerError.TooManyRequests,
+                                "Failed due to heap memory limit exceeded"));
+
+                        return CompletableFuture.completedFuture(null);
+                    }).exceptionally(ex -> {
+                listSizeHolder.resetIfInitializing();
+                writeAndFlush(Commands.newError(clientRequestId, getServerError(ex), ex.getMessage()));
+                return null;
+            });
+        });
+    }
+
+    private CompletableFuture<Void> handleWritingGetTopicsResponse(long clientRequestId, GetTopicsResult r,
+                                                                   BooleanSupplier isCancelled) {
+        BaseCommand responseCommand = Commands.newGetTopicsOfNamespaceResponseCommand(
+                r.getNonPartitionedOrPartitionTopics(), r.getTopicsHash(), r.isFiltered(),
+                r.isChanged(), clientRequestId);
+        return acquireDirectMemoryPermitsAndWriteAndFlush(proxyConnection.ctx(), maxTopicListInFlightLimiter,
+                isCancelled, responseCommand, t -> {
+                    log.warn("[{}] Failed to acquire actual direct memory permits for GetTopicsOfNamespace: {}",
+                            clientAddress, t.getMessage());
+                    writeAndFlush(Commands.newError(clientRequestId, ServerError.TooManyRequests,
+                            "Failed due to direct memory limit exceeded"));
+                    return CompletableFuture.completedFuture(null);
+                });
+    }
+
     public void handleGetSchema(CommandGetSchema commandGetSchema) {
         GET_SCHEMA_REQUESTS.inc();
         if (log.isDebugEnabled()) {
