@@ -32,6 +32,7 @@ import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.atomic.AtomicReferenceFieldUpdater;
 import java.util.concurrent.atomic.LongAdder;
+import lombok.Getter;
 import org.apache.bookkeeper.mledger.ManagedLedger;
 import org.apache.bookkeeper.mledger.Position;
 import org.apache.commons.lang3.StringUtils;
@@ -72,6 +73,7 @@ public class MLTransactionMetadataStore
     private final TransactionCoordinatorID tcID;
     private final MLTransactionLogImpl transactionLog;
     @VisibleForTesting
+    @Getter
     final ConcurrentSkipListMap<Long, Pair<TxnMeta, List<Position>>> txnMetaMap = new ConcurrentSkipListMap<>();
     private final TransactionTimeoutTracker timeoutTracker;
     private final TransactionMetadataStoreStats transactionMetadataStoreStats;
@@ -80,6 +82,9 @@ public class MLTransactionMetadataStore
     private final LongAdder abortedTransactionCount;
     private final LongAdder transactionTimeoutCount;
     private final LongAdder appendLogCount;
+    @Getter
+    @VisibleForTesting
+    private final LongAdder onGoingTxnCount;
     private final MLTransactionSequenceIdGenerator sequenceIdGenerator;
     private final ExecutorService internalPinnedExecutor;
     public final RecoverTimeRecord recoverTime = new RecoverTimeRecord();
@@ -108,6 +113,7 @@ public class MLTransactionMetadataStore
         this.abortedTransactionCount = new LongAdder();
         this.transactionTimeoutCount = new LongAdder();
         this.appendLogCount = new LongAdder();
+        this.onGoingTxnCount = new LongAdder();
         DefaultThreadFactory threadFactory = new DefaultThreadFactory("transaction_coordinator_"
                 + tcID.toString() + "thread_factory");
         this.internalPinnedExecutor = Executors.newSingleThreadScheduledExecutor(threadFactory);
@@ -162,6 +168,7 @@ public class MLTransactionMetadataStore
                                     final TxnMetaImpl left = new TxnMetaImpl(txnID,
                                             openTimestamp, timeoutAt, owner);
                                     txnMetaMap.put(transactionId, MutablePair.of(left, positions));
+                                    onGoingTxnCount.increment();
                                     recoverTracker.handleOpenStatusTransaction(txnSequenceId,
                                             timeoutAt + openTimestamp);
                                 }
@@ -197,8 +204,12 @@ public class MLTransactionMetadataStore
                                     recoverTracker.updateTransactionStatus(txnID.getLeastSigBits(), newStatus);
                                     if (newStatus == TxnStatus.COMMITTED || newStatus == TxnStatus.ABORTED) {
                                         transactionLog.deletePosition(txnMetaMap
-                                                .get(transactionId).getRight()).thenAccept(v ->
-                                                txnMetaMap.remove(transactionId).getLeft());
+                                                .get(transactionId).getRight()).thenAccept(v -> {
+                                                    if (txnMetaMap.remove(transactionId) != null) {
+                                                        onGoingTxnCount.decrement();
+                                                    }
+                                                }
+                                        );
                                     }
                                 }
                                 break;
@@ -237,7 +248,7 @@ public class MLTransactionMetadataStore
     @Override
     public CompletableFuture<TxnID> newTransaction(long timeOut, String owner) {
         if (this.maxActiveTransactionsPerCoordinator == 0
-                || this.maxActiveTransactionsPerCoordinator > txnMetaMap.size()) {
+                || this.maxActiveTransactionsPerCoordinator > onGoingTxnCount.longValue()) {
             CompletableFuture<TxnID> completableFuture = new CompletableFuture<>();
             FutureUtil.safeRunAsync(() -> {
                 if (!checkIfReady()) {
@@ -276,6 +287,7 @@ public class MLTransactionMetadataStore
                                 positions.add(position);
                                 Pair<TxnMeta, List<Position>> pair = MutablePair.of(txn, positions);
                                 txnMetaMap.put(leastSigBits, pair);
+                                onGoingTxnCount.increment();
                                 this.timeoutTracker.addTransaction(leastSigBits, timeOut);
                                 createdTransactionCount.increment();
                                 completableFuture.complete(txnID);
@@ -422,7 +434,9 @@ public class MLTransactionMetadataStore
                                     } else {
                                         abortedTransactionCount.increment();
                                     }
-                                    txnMetaMap.remove(txnID.getLeastSigBits());
+                                    if (txnMetaMap.remove(txnID.getLeastSigBits()) != null) {
+                                        onGoingTxnCount.decrement();
+                                    }
                                     transactionLog.deletePosition(txnMetaListPair.getRight()).exceptionally(ex -> {
                                         log.warn("Failed to delete transaction log position "
                                                 + "at end transaction [{}]", txnID);
@@ -466,7 +480,7 @@ public class MLTransactionMetadataStore
         transactionCoordinatorstats.setLowWaterMark(getLowWaterMark());
         transactionCoordinatorstats.setState(getState().name());
         transactionCoordinatorstats.setLeastSigBits(sequenceIdGenerator.getCurrentSequenceId());
-        transactionCoordinatorstats.ongoingTxnSize = txnMetaMap.size();
+        transactionCoordinatorstats.ongoingTxnSize = onGoingTxnCount.longValue();
         transactionCoordinatorstats.recoverStartTime = recoverTime.getRecoverStartTime();
         transactionCoordinatorstats.recoverEndTime = recoverTime.getRecoverEndTime();
         return transactionCoordinatorstats;
@@ -490,6 +504,7 @@ public class MLTransactionMetadataStore
             internalPinnedExecutor.shutdown();
             return transactionLog.closeAsync().thenCompose(v -> {
                 txnMetaMap.clear();
+                onGoingTxnCount.reset();
                 this.timeoutTracker.close();
                 if (!this.changeToCloseState()) {
                     return FutureUtil.failedFuture(
@@ -508,7 +523,7 @@ public class MLTransactionMetadataStore
     @Override
     public TransactionMetadataStoreStats getMetadataStoreStats() {
         this.transactionMetadataStoreStats.setCoordinatorId(tcID.getId());
-        this.transactionMetadataStoreStats.setActives(txnMetaMap.size());
+        this.transactionMetadataStoreStats.setActives(onGoingTxnCount.intValue());
         this.transactionMetadataStoreStats.setCreatedCount(this.createdTransactionCount.longValue());
         this.transactionMetadataStoreStats.setCommittedCount(this.committedTransactionCount.longValue());
         this.transactionMetadataStoreStats.setAbortedCount(this.abortedTransactionCount.longValue());
