@@ -18,17 +18,15 @@
  */
 package org.apache.pulsar.websocket.service;
 
-import org.apache.pulsar.common.configuration.PulsarConfigurationLoader;
-import org.testng.annotations.Test;
-
+import static org.testng.Assert.assertEquals;
 import java.beans.Introspector;
 import java.beans.PropertyDescriptor;
 import java.io.FileInputStream;
 import java.util.Arrays;
 import java.util.List;
 import java.util.Properties;
-
-import static org.testng.Assert.assertEquals;
+import org.apache.pulsar.common.configuration.PulsarConfigurationLoader;
+import org.testng.annotations.Test;
 
 @Test(groups = "broker")
 public class WebSocketProxyConfigurationTest {
@@ -36,10 +34,13 @@ public class WebSocketProxyConfigurationTest {
     @Test
     public void testConfigFileDefaults() throws Exception {
         try (FileInputStream stream = new FileInputStream("../conf/websocket.conf")) {
-            final WebSocketProxyConfiguration javaConfig = PulsarConfigurationLoader.create(new Properties(), WebSocketProxyConfiguration.class);
-            final WebSocketProxyConfiguration fileConfig = PulsarConfigurationLoader.create(stream, WebSocketProxyConfiguration.class);
+            final WebSocketProxyConfiguration javaConfig =
+                    PulsarConfigurationLoader.create(new Properties(), WebSocketProxyConfiguration.class);
+            final WebSocketProxyConfiguration fileConfig =
+                    PulsarConfigurationLoader.create(stream, WebSocketProxyConfiguration.class);
             List<String> toSkip = Arrays.asList("properties", "class");
-            for (PropertyDescriptor pd : Introspector.getBeanInfo(WebSocketProxyConfiguration.class).getPropertyDescriptors()) {
+            for (PropertyDescriptor pd : Introspector.getBeanInfo(
+                    WebSocketProxyConfiguration.class).getPropertyDescriptors()) {
                 if (pd.getReadMethod() == null || toSkip.contains(pd.getName())) {
                     continue;
                 }
@@ -47,7 +48,8 @@ public class WebSocketProxyConfigurationTest {
                 final Object javaValue = pd.getReadMethod().invoke(javaConfig);
                 final Object fileValue = pd.getReadMethod().invoke(fileConfig);
                 assertEquals(fileValue, javaValue, "property '"
-                        + key + "' conf/websocket.conf default value doesn't match java default value\nConf: " + fileValue + "\nJava: " + javaValue);
+                        + key + "' conf/websocket.conf default value doesn't match java default value\nConf: "
+                        + fileValue + "\nJava: " + javaValue);
             }
         }
     }
